Package 'bddkR'

Title: What the Package Does (Title Case)
Description: The package fetches monthly financial tables and banking sector data published on the official website of the Banking Regulation and Supervision Agency (BRSA, BDDK) of Turkey and also enables you to save it as an Excel file. It is a R implementation of the Python package of [bddkdata](https://pypi.org/project/bddkdata/).
Authors: Ozancan Ozdemir [aut, cre]
Maintainer: Ozancan Ozdemir <[email protected]>
License: MIT + file LICENSE
Version: 0.1.0
Built: 2026-05-13 07:12:00 UTC
Source: https://github.com/ozancanozdemir/bddkr

Help Index


Fetches data from the BDDK API

Description

Fetches data from the BDDK API

Usage

fetch_data(
  start_year,
  start_month,
  end_year,
  end_month,
  table_no,
  currency,
  group,
  lang = "tr",
  save_excel = FALSE
)

Arguments

start_year

integer: Starting year (YYYY format)

start_month

integer: Starting month (1-12)

end_year

integer: Ending year (YYYY format)

end_month

integer: Ending month (1-12)

table_no

integer: Table number (e.g., 1)

currency

character: Currency type (e.g., "TL", "USD")

group

integer: Group type (e.g., 10001)

lang

character: Language selection, default 'tr'

save_excel

logical: If TRUE, saves data to Excel. Default is FALSE.

Value

data.frame: Returns data as a data.frame. Returns NULL if no data is available.